@@ -1,11 +1,12 @@
 package Pod::Elemental::Autoblank;
-our $VERSION = '0.092930';
+our $VERSION = '0.092940';
 
 
 use namespace::autoclean;
 use Moose::Role;
 # ABSTRACT: a paragraph that always displays an extra blank line in Pod form
 
+
 around as_pod_string => sub {
   my ($orig, $self, @arg) = @_;
   my $str = $self->$orig(@arg);
@@ -23,7 +24,15 @@ Pod::Elemental::Autoblank - a paragraph that always displays an extra blank line
 
 =head1 VERSION
 
-version 0.092930
+version 0.092940
+
+=head1 OVERVIEW
+
+This role exists primarily to simplify elements produced by the Pod5
+transformer.  Any element with this role composed into it will append an extra
+newline to the normally generated response to the C<as_pod_string> method.
+
+That's it!
 
 =head1 AUTHOR
 
