@@ -1,5 +1,5 @@
 package Pod::Elemental::Element::Generic::Text;
-our $VERSION = '0.092930';
+our $VERSION = '0.092940';
 
 
 use Moose;
@@ -8,6 +8,7 @@ with 'Pod::Elemental::Flat';
 
 use namespace::autoclean;
 
+
 1;
 
 __END__
@@ -19,7 +20,14 @@ Pod::Elemental::Element::Generic::Text - a POD text or verbatim element
 
 =head1 VERSION
 
-version 0.092930
+version 0.092940
+
+=head1 OVERVIEW
+
+Generic::Text elements represent text paragraphs found in raw Pod.  They are
+likely to be fed to a Pod5 translator and converted to ordinary, verbatim, or
+data paragraphs in that dialect.  Otherwise, Generic::Text paragraphs are
+simple flat paragraphs.
 
 =head1 AUTHOR
 
