@@ -1,11 +1,12 @@
 package Pod::Elemental::Element::Pod5::Nonpod;
-our $VERSION = '0.092930';
+our $VERSION = '0.092940';
 
 
 use Moose;
 with 'Pod::Elemental::Flat';
 with 'Pod::Elemental::Autoblank';
-# ABSTRACT: a non-pod element in a POD document
+# ABSTRACT: a non-pod element in a Pod document
+
 
 use namespace::autoclean;
 
@@ -21,11 +22,26 @@ __END__
 
 =head1 NAME
 
-Pod::Elemental::Element::Pod5::Nonpod - a non-pod element in a POD document
+Pod::Elemental::Element::Pod5::Nonpod - a non-pod element in a Pod document
 
 =head1 VERSION
 
-version 0.092930
+version 0.092940
+
+=head1 OVERVIEW
+
+A Pod5::Nonpod element represents a hunk of non-Pod content found in a Pod
+document tree.  It is equivalent to a
+L<Generic::Nonpod|Pod::Elemental::Element::Generic::Nonpod> element, with the
+following differences:
+
+=over 4
+
+=item * it includes L<Pod::Elemental::Autoblank>
+
+=item * when producing a pod string, it wraps the non-pod content in =cut/=pod
+
+=back
 
 =head1 AUTHOR
 
