@@ -1,5 +1,5 @@
 package Pod::Elemental::Element::Pod5::Verbatim;
-our $VERSION = '0.092930';
+our $VERSION = '0.092940';
 
 
 use Moose;
@@ -7,6 +7,7 @@ extends 'Pod::Elemental::Element::Generic::Text';
 with    'Pod::Elemental::Autoblank';
 # ABSTRACT: a POD verbatim element
 
+
 use namespace::autoclean;
 
 1;
@@ -20,7 +21,18 @@ Pod::Elemental::Element::Pod5::Verbatim - a POD verbatim element
 
 =head1 VERSION
 
-version 0.092930
+version 0.092940
+
+=head1 OVERVIEW
+
+Pod5::Verbatim elements represent "verbatim" paragraphs of text.  These are
+ordinary, flat paragraphs of text that were indented in the source Pod to
+indicate that they should be represented verbatim in formatted output.  The
+following paragraph is a verbatim paragraph:
+
+  This is a verbatim
+      paragraph
+         right here.
 
 =head1 AUTHOR
 
