@@ -1,5 +1,5 @@
 package Pod::Elemental::Node;
-our $VERSION = '0.092930';
+our $VERSION = '0.092940';
 
 
 use Moose::Role;
@@ -47,14 +47,20 @@ Pod::Elemental::Node - a thing with Pod::Elemental::Nodes as children
 
 =head1 VERSION
 
-version 0.092930
+version 0.092940
+
+=head1 OVERVIEW
+
+Classes that include Pod::Elemental::Node represent collections of child
+Pod::Elemental::Paragraphs.  This includes Pod documents, Pod5 regions, and
+nested Pod elements produced by the Gatherer transformer.
 
 =head1 ATTRIBUTES
 
 =head2 children
 
 This attribute is an arrayref of
-L<Pod::Elemental::Node|Pod::Elemental::Node>-doing objects, and represents
+L<Pod::Elemental::Node|Pod::Elemental::Node>-performing objects, and represents
 elements contained by an object.
 
 =head1 AUTHOR
