@@ -1,11 +1,12 @@
 package Pod::Elemental::Objectifier;
-our $VERSION = '0.092930';
+our $VERSION = '0.092940';
 
 
 use Moose;
 use Moose::Autobox;
 # ABSTRACT: it turns a Pod::Eventual event stream into objects
 
+
 use namespace::autoclean;
 
 use Pod::Elemental::Element::Generic::Blank;
@@ -14,6 +15,26 @@ use Pod::Elemental::Element::Generic::Nonpod;
 use Pod::Elemental::Element::Generic::Text;
 
 
+sub objectify_events {
+  my ($self, $events) = @_;
+  return $events->map(sub {
+    Carp::croak("not a valid event") unless ref $_;
+
+    my $class = $self->element_class_for_event($_);
+
+    my %guts = (
+      content    => $_->{content},
+      start_line => $_->{start_line},
+
+      ($_->{type} eq 'command' ? (command => $_->{command}) : ()),
+    );
+
+    $class->new(\%guts);
+  });
+}
+
+
+
 sub __class_for {
   return {
     blank    => 'Pod::Elemental::Element::Generic::Blank',
@@ -33,25 +54,6 @@ sub element_class_for_event {
   return $class_for->{ $t };
 }
 
-
-sub objectify_events {
-  my ($self, $events) = @_;
-  return $events->map(sub {
-    Carp::croak("not a valid event") unless ref $_;
-
-    my $class = $self->element_class_for_event($_);
-
-    my %guts = (
-      content    => $_->{content},
-      start_line => $_->{start_line},
-
-      ($_->{type} eq 'command' ? (command => $_->{command}) : ()),
-    );
-
-    $class->new(\%guts);
-  });
-}
-
 1;
 
 __END__
@@ -63,24 +65,37 @@ Pod::Elemental::Objectifier - it turns a Pod::Eventual event stream into objects
 
 =head1 VERSION
 
-version 0.092930
+version 0.092940
 
-=head1 METHODS
+=head1 OVERVIEW
 
-=head2 element_class_for_event
+An objectifier is responsible for taking the events produced by
+L<Pod::Eventual|Pod::Eventual> and converting them into objects that perform
+the Pod::Elemental::Paragraph role.
 
-This method returns the name of the class to be used for the given event.
+In general, it does this by producing a sequence of element objects in the
+Pod::Elemental::Element::Generic namespace.
 
 =cut
 
 =pod
 
+=head1 METHODS
+
 =head2 objectify_events
 
   my $elements = $objectifier->objectify_events(\@events);
 
-Given an arrayref of POD events, this method returns an arrayref of
-Pod::Elemental::Element objects formed from the event stream.
+Given an arrayref of Pod events, this method returns an arrayref of objects
+formed from the event stream.
+
+=cut
+
+=pod
+
+=head2 element_class_for_event
+
+This method returns the name of the class to be used for the given event.
 
 =head1 AUTHOR
 
