@@ -1,11 +1,12 @@
 package Pod::Elemental::Transformer::Nester;
-our $VERSION = '0.092930';
+our $VERSION = '0.092940';
 
 
 use Moose;
 with 'Pod::Elemental::Transformer';
 # ABSTRACT: group the document into sections
 
+
 use Moose::Autobox 0.10;
 use MooseX::Types::Moose qw(ArrayRef CodeRef);
 
@@ -14,16 +15,6 @@ use Pod::Elemental::Selectors -all;
 
 use namespace::autoclean;
 
-# so here you'll specify something like:
-#   head1  => [ things it can contain / things it can't contain ]
-#   method => [ things it can contain / things it can't contain ]
-# and it will go through the list of paragraphs, and nest all the "things a
-# head1 can contain" under the head1, if they are subsequent to it
-#
-# we'll enforce the rule that nothing that can be contained can also be a
-# container, if possible; probably not possible :-/
-#
-# DEFAULT: head1 => [ allow: =head2.., =over, =item, =back, *text ]
 
 has top_selector => (
   is  => 'ro',
@@ -31,6 +22,7 @@ has top_selector => (
   required => 1,
 );
 
+
 has content_selectors => (
   is  => 'ro',
   isa => ArrayRef[ CodeRef ],
@@ -99,7 +91,74 @@ Pod::Elemental::Transformer::Nester - group the document into sections
 
 =head1 VERSION
 
-version 0.092930
+version 0.092940
+
+=head1 OVERVIEW
+
+The Nester transformer is meant to find potential container elements and make
+them into actual containers.  It works by being told what elements may be made
+into containers and what subsequent elements they should allow to be stuffed
+into them.
+
+For example, given the following nester:
+
+  use Pod::Elemental::Selectors qw(s_command s_flat);
+
+  my $nester = Pod::Elemental::Transformer::Nester->new({
+    top_selector      => s_command('head1'),
+    content_selectors => [
+      s_command([ qw(head2 head3 head4) ]),
+      s_flat,
+    ],
+  });
+
+..then when we apply the transformation:
+
+  $nester->transform_node($document);
+
+...the nester will find all C<=head1> elements in the top-level of the
+document.  It will ensure that they are represented by objects that perform the
+Pod::Elemental::Node role, and then it will move all subsequent elements
+matching the C<content_selectors> into the container.
+
+So, if we start with this input:
+
+  =head1 Header
+  =head2 Subheader
+  Pod5::Ordinary <some content>
+  =head1 New Header
+
+The nester will convert its structure to look like this:
+
+  =head1 Header
+    =head2 Subheader
+    Pod5::Ordinary <some content>
+  =head1 New Header
+
+Once an element is reached that does not pass the content selectors, the
+nesting ceases until the next potential container.
+
+=cut
+
+=pod
+
+=head1 ATTRIBUTES
+
+=head2 top_selector
+
+This attribute must be a coderef (presumably made from
+Pod::Elemental::Selectors) that will test elements in the transformed node and
+return true if the element is a potential new container.
+
+=cut
+
+=pod
+
+=head2 content_selectors
+
+This attribute must be an arrayref of coderefs (again presumably made from
+Pod::Elemental::Selectors) that will test whether paragraphs subsequent to the
+top-level container may be moved under the container.
 
 =head1 AUTHOR
 
