@@ -1,11 +1,12 @@
 package Pod::Elemental::Transformer::Pod5;
-our $VERSION = '0.092930';
+our $VERSION = '0.092940';
 
 
 use Moose;
 with 'Pod::Elemental::Transformer';
 # ABSTRACT: the default, minimal semantics of Perl5's pod element hierarchy
 
+
 use Moose::Autobox 0.10;
 
 use namespace::autoclean;
@@ -20,8 +21,6 @@ use Pod::Elemental::Element::Pod5::Region;
 
 use Pod::Elemental::Selectors -all;
 
-# TODO: handle the stupid verbatim-correction when inside non-colon-begin
-
 sub _gen_class { "Pod::Elemental::Element::Generic::$_[1]" }
 sub _class     { "Pod::Elemental::Element::Pod5::$_[1]" }
 
@@ -170,7 +169,7 @@ sub _autotype_paras {
 sub __text_class {
   my ($self, $para) = @_;
 
-  for my $type (qw(Ordinary Verbatim Data)) {
+  for my $type (qw(Verbatim Data)) {
     my $class = $self->_class($type);
     return $class if $para->isa($class);
   }
@@ -252,7 +251,46 @@ Pod::Elemental::Transformer::Pod5 - the default, minimal semantics of Perl5's po
 
 =head1 VERSION
 
-version 0.092930
+version 0.092940
+
+=head1 SYNOPSIS
+
+  Pod::Elemental::Transformer::Pod5->new->transform_node($pod_elem_document);
+
+...and that's it.
+
+=head1 OVERVIEW
+
+The Pod5 transformer is meant to be used to convert the result of a "stock"
+Pod::Elemental::Document into something simpler to work with.  It assumes that
+the document conforms more or less to the convetions laid out in L<perlpod> and
+L<perlpodspec>.  It is not very strict, and makes very few assumptions,
+described here:
+
+=over 4
+
+=item * =begin/=end and =for enclose or produce regions within the document
+
+=item * regions are associated with format names; format names that begin with a colon enclose more pod-like content
+
+=item * regions nest strictly; all inner regions must end before outer regions
+
+=item * paragraphs in non-pod regions are "data" paragraphs
+
+=item * non-data paragraphs that start with spaces are "verbatim" paragraphs
+
+=item * groups of data or verbatim paragraphs can be consolodated
+
+=back
+
+Further, all elements are replaced with equivalent elements that perform the
+L<Pod::Elemental::Autoblank> role, so all "blank" events can be removed form
+the tree and ignored.
+
+=head1 CONFIGURATION
+
+None.  For now, it just does the same thing every time with no configuration or
+options.
 
 =head1 AUTHOR
 
